def calculate_liquid_volume_container_2segments_square_vbottom(
  x: float,
  y: float,
  h_pyramid: float,
  h_cube: float,
  liquid_height: float,
) -> float:
  """
  This function is deprecated. Please use the equivalent function in
  src/pylabrobot/pylabrobot/resources/height_volume_functions.py
  """
  raise DeprecationWarning(
    "This function is deprecated. Please use the equivalent function in "
    "src/pylabrobot/pylabrobot/resources/height_volume_functions.py"
  )


def calculate_liquid_volume_container_2segments_square_ubottom(
  x: float, h_cuboid: float, liquid_height: float
) -> float:
  """
  This function is deprecated. Please use the equivalent function in
  src/pylabrobot/pylabrobot/resources/height_volume_functions.py
  """
  raise DeprecationWarning(
    "This function is deprecated. Please use the equivalent function in "
    "src/pylabrobot/pylabrobot/resources/height_volume_functions.py"
  )


def calculate_liquid_volume_container_2segments_round_vbottom(
  d: float, h_cone: float, h_cylinder: float, liquid_height: float
) -> float:
  """
  This function is deprecated. Please use the equivalent function in
  src/pylabrobot/pylabrobot/resources/height_volume_functions.py
  """
  raise DeprecationWarning(
    "This function is deprecated. Please use the equivalent function in "
    "src/pylabrobot/pylabrobot/resources/height_volume_functions.py"
  )


def calculate_liquid_volume_container_2segments_round_ubottom(
  d: float, h_cylinder: float, liquid_height: float
) -> float:
  """
  This function is deprecated. Please use the equivalent function in
  src/pylabrobot/pylabrobot/resources/height_volume_functions.py
  """
  raise DeprecationWarning(
    "This function is deprecated. Please use the equivalent function in "
    "src/pylabrobot/pylabrobot/resources/height_volume_functions.py"
  )


def calculate_liquid_volume_container_1segment_round_fbottom(
  d: float, h_cylinder: float, liquid_height: float
) -> float:
  """
  This function is deprecated. Please use the equivalent function in
  src/pylabrobot/pylabrobot/resources/height_volume_functions.py
  """
  raise DeprecationWarning(
    "This function is deprecated. Please use the equivalent function in "
    "src/pylabrobot/pylabrobot/resources/height_volume_functions.py"
  )
